"""SNAPstraction over raw SNAPbuild calls"""

import logging

import os
import subprocess
import sys

from distutils.sysconfig import get_python_lib

log = logging.getLogger(__name__)


def build(parser, context, args):
    """Build commands"""

    # Just in time import
    try:
        from snapbuild import snapbuild
    except ImportError:
        log.exception("SNAPbuild not installed.")
        raise

    log.info("build context: %r", context)
    log.info("build args: %r", args)

    addl_includes = []

    # This is a check for "Are we being executed under an active virtualenv?"
    # Different from "Are we installed in a virtualenv"
    if 'VIRTUAL_ENV' in os.environ:
        addl_includes.insert(
            0,
            os.path.abspath(get_python_lib(prefix=os.environ['VIRTUAL_ENV'])))

    addl_includes.append(get_python_lib())

    snapbuild_args = [snapbuild.SNAPBUILD_PATH]

    for i in addl_includes:
        snapbuild_args.append('-I')
        snapbuild_args.append(i)

    log.info("Calling SNAPBuild with args: %r", snapbuild_args + args)

    # TODO: Push this down to the snapbuild wrapper? Something like...
    # out, err, rc = snapbuild.run(args)
    sb = subprocess.Popen(snapbuild_args + args,
                          stdout=subprocess.PIPE,
                          stderr=subprocess.PIPE)
    out, err = sb.communicate()

    sys.stderr.write(err)
    sys.stdout.write(out)

    exit(sb.returncode)
