import datetime
import gzip
import logging
import os

LOG_PATH = os.path.expanduser(os.path.join('~', '.snap', 'cmdlog.txt.gz'))

log = logging.getLogger(__name__)


def _sanitize_node_nvparam(args):
    if 'node' in args and 'nvparam' in args:
        nvparam_idx = args.index('nvparam')
        # Are there enough args left to check?
        if len(args) > nvparam_idx + 2:
            param = args[nvparam_idx + 1]
            if param in ('51', 'security.encryption-key'):
                args[nvparam_idx + 2] = "****************"

    return args


def _sanitize_config_encryption(args):
    if 'config' in args:
        cfg_idx = args.index('config')
        # Enough args left to check?
        if len(args) > cfg_idx + 4:
            cmd = args[cfg_idx + 3]
            if cmd in ('encryption_key'):
                args[cfg_idx + 4] = "****************"

    return args


def _sanitize_args(cmd_args):
    """Intent here is to obfuscate obviously sensitive info like network keys"""
    # Catch snap node FOO nvparam commands....
    try:
        cmd_args = _sanitize_node_nvparam(cmd_args)
    except:
        pass

    # Catch snap config network FOO encryption_key MASK_THIS
    try:
        cmd_args = _sanitize_config_encryption(cmd_args)
    except:
        pass

    return cmd_args


def log_command(cmd_args):
    """Log the command."""
    cmd_args = _sanitize_args(cmd_args)

    try:
        with gzip.open(LOG_PATH, 'a') as f:
            f.write('%s\t' % (datetime.datetime.utcnow().isoformat(), ) +
                    ' '.join(cmd_args) + '\n')
    except:
        log.debug("Couldn't log command to %s", LOG_PATH)
