"""Output formatters for SNAPtoolbelt"""
import sys


def dkvp_formatter():
    """Create a Delimited Key-Value Pair formatter"""

    # DKVP - http://johnkerl.org/miller/doc/record-heterogeneity.html
    def output(obj):
        """DKVP output"""

        def dict_output(obj):
            """DKVP for dictionaries"""
            print ",".join(["%s=%s" % (str(k).strip(), str(v).strip()) for k, v
                            in sorted(obj.iteritems())])

        def list_output(obj):
            """DKVP for lists/tuples"""
            for item in obj:
                dict_output(item)

        if isinstance(obj, dict):
            dict_output(obj)
        elif isinstance(obj, list) or isinstance(obj, tuple):
            list_output(obj)
        elif isinstance(obj, basestring):
            print obj

        sys.stdout.flush()

    return output


def json_formatter():
    """Create a JSON formatter"""
    import json

    def output(obj):
        """JSON output"""
        print json.dumps(obj, sort_keys=True)
        sys.stdout.flush()

    return output


def json_pretty_formatter():
    """Create a JSON 'pretty-print' formatter"""
    import json

    def output(obj):
        """JSON output"""
        print json.dumps(obj, sort_keys=True, indent=4, default=str)
        sys.stdout.flush()

    return output


FORMATS = {
    'dkvp': dkvp_formatter,
    'json': json_formatter,
    'json-pretty': json_pretty_formatter,
}
